pub struct DeviceCode {
pub expires: DateTime<Utc>,
pub user_code: String,
pub verification_uri: String,
pub verification_uri_complete: Option<String>,
/* private fields */
}Available on crate feature
device-code only.Fields
expires: DateTime<Utc>user_code: Stringverification_uri: Stringverification_uri_complete: Option<String>Implementations
Sourceimpl DeviceCode
impl DeviceCode
Sourcepub async fn request(
issuer: &str,
client_id: String,
) -> Result<Self, RauthyError>
pub async fn request( issuer: &str, client_id: String, ) -> Result<Self, RauthyError>
Request a device_code from your Rauthy instance.
This code can then be used in exchange for an OIDC Token Set.
Clients requesting device_code’s are typically public. If you have a confidential
client or need additional configuration, use DeviceCode::request_with().
Sourcepub async fn request_with(
issuer: &str,
client_id: String,
client_secret: Option<String>,
scope: Option<&str>,
root_certificate: Option<RootCertificate>,
https_only: RauthyHttpsOnly,
danger_insecure: DangerAcceptInvalidCerts,
) -> Result<Self, RauthyError>
pub async fn request_with( issuer: &str, client_id: String, client_secret: Option<String>, scope: Option<&str>, root_certificate: Option<RootCertificate>, https_only: RauthyHttpsOnly, danger_insecure: DangerAcceptInvalidCerts, ) -> Result<Self, RauthyError>
Request a device_code from your Rauthy instance.
This code can then be used in exchange for an OIDC Token Set.
Sourcepub async fn wait_for_token(&mut self) -> Result<OidcTokenSet, RauthyError>
pub async fn wait_for_token(&mut self) -> Result<OidcTokenSet, RauthyError>
With a valid device_code, continuously poll the Rauthy instance and wait
for user verification of your request, to get an OIDC Token Set.