Module handler

Module handler 

The api which need to be called from your endpoints

Structs

OidcCallbackParams
Query params appended to the callback URL after a successful login from the user

Enums

OidcCookieInsecure
Used instead of a normal bool to never confuse people about a meaning of multiple bool’s
OidcSetRedirectStatus
Used instead of a normal bool to never confuse people about a meaning of multiple bool’s

Functions

oidc_callback
Handles the OIDC callback
validate_principal_genericNeither actix-web nor axum
Check the authentication